@@ -1,5 +1,5 @@
 /* gifsicle.h - Function declarations for gifsicle.
-   Copyright (C) 1997-2007 Eddie Kohler, eddietwo@lcs.mit.edu
+   Copyright (C) 1997-2008 Eddie Kohler, ekohler@gmail.com
    This file is part of gifsicle.
 
    Gifsicle is free software. It is distributed under the GNU Public License,
@@ -133,7 +133,7 @@ void fatal_error(const char *message, ...) NORETURN;
 void warning(const char *message, ...);
 void warncontext(const char *message, ...);
 void error(const char *message, ...);
-void clp_error_handler(const char *clp_message);
+void clp_error_handler(Clp_Parser *clp, const char *clp_message);
 void usage(void);
 void short_usage(void);
 
